LATheme class
Colors applied around the rendered trees.
Constructors
Properties
- background → Color?
-
Lock-screen banner background.
nullkeeps the system material.final -
backgroundGradient
→ List<
Color> ? -
Two or more colors, painted top-leading → bottom-trailing.
final
- foreground → Color?
-
Default text color for every node that does not set its own.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tint → Color?
-
.keylineTintfor the Dynamic Island — the glow around the island when the activity updates.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited